<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>
        <%title%>
    </title>
    css-scope
    hightlight-css
    <link rel="icon" href="<%favicon%>">
</head>

<body class="light">
    github-icon
    html-scope
    directory-tree-scope
    <div class="zood"><a class="" href="https://github.com/luzhixing12345/zood" target="_blank">zood</a></div>
    js-scope
</body>

</html>